@@ -166,7 +166,7 @@ sub feature {
   
   require Module::Build;  # XXX should get rid of this
   while (my ($type, $prereqs) = each %%info) {
-    next if $type eq 'description';
+    next if $type eq 'description' || $type eq 'recommends';
     
     my %%p = %%$prereqs;  # Ditto here.
     while (my ($modname, $spec) = each %%p) {
@@ -186,6 +186,7 @@ EOF
 
 $notes_name - Configuration for $module_name
 
+
 =head1 SYNOPSIS
 
   use $notes_name;
@@ -199,6 +200,7 @@ $notes_name - Configuration for $module_name
   $notes_name->set_feature(bar => \$new_value);
   $notes_name->write;  # Save changes
 
+
 =head1 DESCRIPTION
 
 This module holds the configuration data for the C<$module_name>
@@ -208,6 +210,7 @@ changes, you'll have to have write access to the C<$notes_name>
 module, and you should attempt to understand the repercussions of your
 actions.
 
+
 =head1 METHODS
 
 =over 4
@@ -259,6 +262,7 @@ Requires write access to the C<$notes_name> module.
 
 =back
 
+
 =head1 AUTHOR
 
 C<$notes_name> was automatically created using C<Module::Build>.
